from typing import Final


class OAPI:

    ApplicationJson: Final[str] = "application/json"

    Components: Final[str] = "components"
    Content: Final[str] = "content"

    Get: Final[str] = "get"

    Paths: Final[str] = "paths"
    Post: Final[str] = "post"

    RequestBody: Final[str] = "requestBody"
    Required: Final[str] = "required"
    Responses: Final[str] = "responses"

    Schema: Final[str] = "schema"





from typing import Final


class UrlRef:
    AWS: Final[str] = "https://958e36p8n5.execute-api.ap-northeast-1.amazonaws.com/prod/"
    LocalNodeJs: Final[str] = "http://localhost:33000/"


class Url:
    Root = UrlRef.AWS



from aenum import IntEnum
from volworld_common.api.enum.common_error_code import CommonErrorCode


class ErrorCode(IntEnum):

    NoError = CommonErrorCode.NoError.value

    UserNameExisting = 1001

